@@ -5,6 +5,7 @@ use attributes ();
 use base 'Terse::Controller';
 use B 'svref_2object';
 use Cwd qw(abs_path cwd);
+use Module::Runtime qw/require_module/;
 
 sub start {
 	my ($pkg, %args) = @_;
@@ -95,9 +96,7 @@ sub _load_modules {
 	} $self->_recurse_directory("$args{path}/$type");
 	my %mods = ();
 	for my $module (@modules) {
-		no warnings 'reserved';
-		eval "require $module->[1]";
-		die $@ if $@;
+		require_module($module->[1]);
 	}
 	for my $module (@modules) {
 		$module = $module->[1]->new(app => 1);
@@ -188,7 +187,7 @@ Terse::App - Lightweight MVC applications.
 
 =head1 VERSION
 
-Version 0.123456
+Version 0.1234567
 
 =cut
 
